<?php

namespace App\Http\Controllers;

use App\Models\Order;
use App\Models\OrderDetail;
use App\Traits\GenerateRef;
use Illuminate\Http\Request;

class OrderController extends Controller
{
    use GenerateRef;

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {
        return Order::with('order_details.design_master', 'customer', 'user', 'payment')->latest()->get();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {
        $order = new Order();

        $order->fill($request->except('order_details', 'signed_stamp'));
        $order->order_id = 'OR_'.$this->generateRef(new Order);

        if ($request->hasFile('signed_stamp')) {
            $filename = $request->file('signed_stamp')->hashName();
            $request->file('signed_stamp')->move(storage_path('app/public/orders'), $filename);
            $order->signed_stamp = $filename;
        }
        $order->is_use_status = 0;
        $order->save();

        if ($request->has('order_details')) {

            foreach (json_decode($request->order_details, true) as $od) {
                // foreach ($request->order_details as $od) {
                $newOd = OrderDetail::create($od);
                $newOd->order_id = $order->id;
                $newOd->save();
            }
        }

        return $order;
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Order  $order
     * @return \Illuminate\Http\Response
     */
    public function show(Order $order) {
        return Order::where('id', $order->id)->with('order_details.design_master', 'customer', 'user',
            'payment')->first();
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Order  $order
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Order $order) {

        $order->fill($request->except('order_details', 'order_id', 'delete_order_detail_ids', 'signed_stamp'));
        if ($request->hasFile('signed_stamp')) {
            $filename = $request->file('signed_stamp')->hashName();
            $request->file('signed_stamp')->move(storage_path('app/public/orders'), $filename);
            $order->signed_stamp = $filename;
        }
        $order->save();

        if ($request->has('order_details')) {
            foreach (json_decode($request->order_details, true) as $od) {
                if (isset($od['id'])) {
                    $oldOd = OrderDetail::find($od['id']);
                    $oldOd->fill($od);
                    $oldOd->order_id = $order->id;
                    $oldOd->save();
                } else {
                    $newOd = OrderDetail::create($od);
                    $newOd->order_id = $order->id;
                    $newOd->save();
                }
            }
        }

        if ($request->has('delete_order_detail_ids')) {
            OrderDetail::where('id', json_decode($request->delete_order_detail_ids, true))->delete();
        }

        return $order;
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Order  $order
     * @return \Illuminate\Http\Response
     */
    public function destroy(Order $order) {
        // OrderDetail::where('order_id', $order->id)->delete();
        return $order->delete();
    }
}
