<?php

namespace App\Http\Controllers;

use App\Models\Order;
use App\Models\Product;
use App\Models\PurchaseOrder;
use App\Models\PurchaseOrderDetail;
use App\Traits\GenerateRef;
use Illuminate\Http\Request;

class PurchaseOrderController extends Controller
{
    use GenerateRef;

    public function index() {
        return PurchaseOrder::with([
            'supplier',
            'order',
            'purchase_order_details.product',
            'purchase_order_histories.product'
        ])->latest()->get();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {

        // Check if the order ID exists and if is_use_status is already set to 1
        $order = Order::where('id', $request->order_id)->first();

        if ($order && $order->is_use_status == 1) {
            return response()->json(['error' => 'This order is already in use and cannot be Add.'], 400);
        }

        // If the order exists and is not in use, set is_use_status to 1
        if ($order) {
            $order->is_use_status = 1;
            $order->save();
        }
        $purchaseOrder = new PurchaseOrder();

        $purchaseOrder->fill($request->except('purchase_order_details'));
        $purchaseOrder->po_id = 'PO_'.$this->generateRef(new PurchaseOrder);
        $purchaseOrder->save();

        if ($request->has('purchase_order_details')) {
            foreach ($request->purchase_order_details as $od) {
                $newOd = PurchaseOrderDetail::create($od);
                $newOd->purchase_order_id = $purchaseOrder->id;
                $newOd->save();
            }
        }

        return $purchaseOrder;
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\PurchaseOrder  $purchaseOrder
     * @return \Illuminate\Http\Response
     */
    public function show(PurchaseOrder $purchaseOrder) {
        return PurchaseOrder::where('id', $purchaseOrder->id)->with('purchase_order_details.product', 'supplier',
            'order', 'purchase_order_histories.product')->first();
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\PurchaseOrder  $purchaseOrder
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, PurchaseOrder $purchaseOrder) {

        // // Check if the order ID exists and if is_use_status is already set to 1
        // $order = Order::where('id', $purchaseOrder->order_id)->first();

        // if ($order && $order->is_use_status == 1) {
        // return response()->json(['error' => 'This order is already in use and cannot be updated.'], 400);
        // }

        // // If the order exists and is not in use, set is_use_status to 1
        // if ($order) {
        // $order->is_use_status = 1;
        // $order->save();
        // }


        $purchaseOrder->fill($request->except('purchase_order_details', 'po_id', 'delete_purchase_order_detail_ids'));
        $purchaseOrder->save();

        if ($request->has('purchase_order_details')) {
            foreach ($request->purchase_order_details as $od) {
                if (isset($od['id'])) {
                    $oldOd = PurchaseOrderDetail::find($od['id']);
                    $oldQty = $oldOd->qty;
                    $oldOd->fill($od);
                    $oldOd->purchase_order_id = $purchaseOrder->id;
                    $oldOd->save();


                    // $product = Product::find($oldOd['product_id']);
                    // $product->quantity += abs(((int)$oldQty - (int)$oldOd->qty));
                    // $product->save();
                } else {
                    $newOd = PurchaseOrderDetail::create($od);
                    $newOd->purchase_order_id = $purchaseOrder->id;
                    $newOd->save();

                    // $product = Product::find($newOd['product_id']);
                    // $product->quantity += (int)$newOd['qty'];
                    // $product->save();
                }
            }
        }

        if ($request->has('delete_purchase_order_detail_ids')) {
            // foreach ($request->delete_purchase_order_detail_ids as $id) {
            //     $pod = PurchaseOrderDetail::find($id);
            //     $product = Product::find($pod->product_id);
            //     $product->quantity -= $pod->qty;
            //     $product->save();
            // }
            PurchaseOrderDetail::where('id', $request->delete_purchase_order_detail_ids)->delete();
        }

        if ($purchaseOrder->is_inward_approved) {
            foreach ($purchaseOrder->purchase_order_details as $detail) {
                $product = Product::find($detail->product_id);
                $product->quantity += $detail->receive_qty;
                $product->save();
            }
        }

        // if ($purchaseOrder->is_inward_approved) {
        //     foreach ($purchaseOrder->purchase_order_details as $detail) {
        //         $detail->product->quantity += $detail->qty;
        //         $detail->product->save();
        //     }
        // }


        return $purchaseOrder;
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\PurchaseOrder  $purchaseOrder
     * @return \Illuminate\Http\Response
     */
    // public function destroy(PurchaseOrder $purchaseOrder)
    // {

    //     $purchase_order = PurchaseOrderDetail::where('id', $purchaseOrder->id)->first();
    //     print_r($purchase_order->order_id);
    //     exit;
    //     $order = Order::where('id', $request->order_id)->first();

    //     if ($order && $order->is_use_status == 1) {
    //     return response()->json(['error' => 'This order is already in use and cannot be Add.'], 400);
    //     }

    //     // If the order exists and is not in use, set is_use_status to 1
    //     if ($order) {
    //     $order->is_use_status = 1;
    //     $order->save();
    //     }
    //     PurchaseOrderDetail::where('purchase_order_id', $purchaseOrder->id)->delete();
    //     return $purchaseOrder->delete();
    // }

    public function destroy(PurchaseOrder $purchaseOrder) {

        $purchaseOrderDetail = PurchaseOrder::where('id', $purchaseOrder->id)->first();

        // print_r($purchaseOrderDetail->order_id);exit;
        if ($purchaseOrderDetail) {
            $order = Order::where('id', $purchaseOrderDetail->order_id)->first();


            // if ($order && $order->is_use_status == 1) {
            //     return response()->json(['error' => 'This order is already in use and cannot be deleted.'], 400);
            // }


            if ($order) {
                $order->is_use_status = 0;
                $order->save();
            }
        }
        PurchaseOrderDetail::where('purchase_order_id', $purchaseOrder->id)->delete();

        return $purchaseOrder->delete();
    }
}
