<?php

namespace App\Http\Controllers;

use App\Models\YarnIssue;
use App\Models\YarnIssueDetail;
use Illuminate\Http\Request;

class YarnIssueController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {
//        return YarnIssue::with('yarn_issue_details.product', 'yarn_issue_details.design', 'designDetail', 'order')->latest()->get();
        return YarnIssue::with([
            'yarn_issue_details.product',
            'yarn_issue_details.design',
            'designDetail',
            'order'
        ])->latest()->get();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {
        $yarnIssue = new YarnIssue();

        $yarnIssue->fill($request->except('yarn_issue_details'));
        $yarnIssue->save();

        if ($request->has('yarn_issue_details')) {
            foreach ($request->yarn_issue_details as $od) {
                $newOd = YarnIssueDetail::create($od);
                $newOd->yarn_issue_id = $yarnIssue->id;
                $newOd->save();
            }
        }

        return $yarnIssue;
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\YarnIssue  $yarnIssue
     * @return \Illuminate\Http\Response
     */
    public function show(YarnIssue $yarnIssue) {
        return YarnIssue::where('id', $yarnIssue->id)->with('yarn_issue_details.product',
            'yarn_issue_details.design')->first();
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\YarnIssue  $yarnIssue
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, YarnIssue $yarnIssue) {

        $yarnIssue->fill($request->except('yarn_issue_details', 'po_id', 'delete_yarn_issue_detail_ids'));
        $yarnIssue->save();

        if ($request->has('yarn_issue_details')) {
            foreach ($request->yarn_issue_details as $od) {
                if (isset($od['id'])) {
                    $oldOd = YarnIssueDetail::find($od['id']);
                    $oldOd->fill($od);
                    $oldOd->yarn_issue_id = $yarnIssue->id;
                    $oldOd->save();
                } else {
                    $newOd = YarnIssueDetail::create($od);
                    $newOd->yarn_issue_id = $yarnIssue->id;
                    $newOd->save();
                }
            }
        }

        if ($request->has('delete_yarn_issue_detail_ids')) {
            YarnIssueDetail::where('id', $request->delete_yarn_issue_detail_ids)->delete();
        }


        return $yarnIssue;
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\YarnIssue  $yarnIssue
     * @return \Illuminate\Http\Response
     */
    public function destroy(YarnIssue $yarnIssue) {
        YarnIssueDetail::where('yarn_issue_id', $yarnIssue->id)->delete();
        return $yarnIssue->delete();
    }
}
